# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-05-20 04:12
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import djangocms_attributes_field.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AnimateOnScroll_Anchor',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='djangocms_animate_on_scroll_animateonscroll_anchor', serialize=False, to='cms.CMSPlugin')),
                ('id_name', models.CharField(max_length=255, verbose_name='ID name')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='AnimateOnScroll_Element',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='djangocms_animate_on_scroll_animateonscroll_element', serialize=False, to='cms.CMSPlugin')),
                ('aos_animation', models.CharField(help_text='Script will trigger "animation_name" animation on this element, if you scroll to it.', max_length=255, verbose_name='AOS Animation')),
                ('aos_easing', models.CharField(blank=True, help_text='Choose timing function to ease elements in different ways', max_length=255, verbose_name='Anchor Easing')),
                ('aos_anchor_placement', models.CharField(blank=True, help_text='Anchor placement - which one position of element on the screen should trigger animation', max_length=255, verbose_name='Anchor Placement')),
                ('aos_offset', models.IntegerField(default=120, help_text='Change offset to trigger animations sooner or later (px)', verbose_name='Offset')),
                ('aos_duration', models.IntegerField(default=400, help_text='*Duration of animation (ms)', verbose_name='Duration')),
                ('aos_delay', models.IntegerField(default=0, help_text='Delay animation (ms)', verbose_name='Delay')),
                ('aos_once', models.BooleanField(default=False, help_text='Choose wheter animation should fire once, or every time you scroll up/down to element', verbose_name='Once')),
                ('id_name', models.CharField(blank=True, max_length=255, verbose_name='ID name')),
                ('additional_classes', models.CharField(blank=True, help_text='Additional comma separated list of classes to be added to the element e.g. "row, column-12, clearfix".', max_length=255, verbose_name='Additional classes')),
                ('attributes', djangocms_attributes_field.fields.AttributesField(blank=True, default=dict, verbose_name='Attributes')),
                ('aos_anchor', models.ForeignKey(blank=True, help_text='Anchor element, whose offset will be counted to trigger animation instead of actual elements offset', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='aos_anchor', to='djangocms_animate_on_scroll.AnimateOnScroll_Anchor', verbose_name='Animate On Scroll Anchor')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
